Skip to contents

Load an MGH file into memory

Usage

load.mgh(file_path, as_vector = TRUE)

Arguments

file_path

The (full) path to the mgh file.

as_vector

Logical. Return the entire object or just the vertex values as a vector.

Value

A mgh object with data and various header elements

Author

Heath Perdoe, 2013.