Creates a gzip-compressed tar archive containing a sufficient statistics from the local site. The archive is written to the output directory and can be safely shared among insititutions
Arguments
- outp_dir
Character scalar. Directory containing the local output files to be packaged (e.g., FBM
.rds+.bkpairs and other.rdsobjects).- site_name
Character scalar. Site identifier used as the archive basename (output file will be
{site_name}.tar.gz).- then_rm_files
Logical. Remove input files after compressing them? Default: TRUE.