Prepare progress-tracking metadata for a given chunk of vertices. When
verbose = TRUE, prints a message indicating which chunk is being
processed and returns markers for 25\
that chunk.
Arguments
- chunk
Integer vector of vertex indices for the current chunk. Expected to be an element of
chunk_seqcreated bymake_chunk_sequence.- chunk_seq
Full list of chunks (as returned by
make_chunk_sequence), used to compute the total number of chunks.- verbose
Logical; if
TRUE, prints progress messages.