Get the terms for the (fixed) effect for the given formula.
Wors for lme4 as well as regular lm style formulas.
Arguments
- formula
A formula object, for example specifying a LME model.
- df
A data.frame, for example the first element in the list output of
imp2list.- return_X
Logical. Whether to return the whole design matrix or just the (fixed) term names.