Calculates the absolute difference (a - b) between two cortical surface maps
for both the left and right hemispheres. Prints statistical summaries of the
difference distribution.
Arguments
- lh_a, lh_b
Left hemisphere data maps (numeric vectors or file paths) to contrast.
- rh_a, rh_b
Right hemisphere data maps (numeric vectors or file paths) to contrast.
- label_a
Character string representing the name of the first map (
a).- label_b
Character string representing the name of the second map (
b).